@@ -1,26 +1,28 @@
 package Time::Elapsed::Lang::TR;
 use strict;
+use warnings;
 use vars qw( $VERSION        );
 use subs qw( singular plural );
 use utf8;
 
-$VERSION = '0.29';
+$VERSION = '0.31';
 
 *plural = \&singular;
 
 sub singular {
-   qw/
+   return qw/
    second  saniye
    minute  dakika
    hour    saat
    day     gün
+   week    hafta
    month   ay
    year    yıl
    /
 }
 
 sub other {
-   qw/
+   return qw/
    and     ve
    ago     önce
    /,
@@ -45,8 +47,8 @@ Private module.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.29> of C<Time::Elapsed::Lang::TR>
-released on C<23 April 2009>.
+This document describes version C<0.31> of C<Time::Elapsed::Lang::TR>
+released on C<9 February 2011>.
 
 Private module.
 
@@ -64,16 +66,16 @@ L<Time::Elapsed>.
 
 =head1 AUTHOR
 
-Burak Gürsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2007-2008 Burak Gürsoy. All rights reserved.
+Copyright 2007 - 2011 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.8.8 or, 
+it under the same terms as Perl itself, either Perl version 5.12.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
